*** Mehr als konomisches Kalkl? Zu den Bestimmungsgrnden von auf die Euro-Krise 
*** bezogenen Performanzbewertungen und Policy-Prferenzen 
*** Agatha Rudnik/Harald Schoen
*** GLES Wahlkampf-Panel 2009 & 2013

*** Stata Version 13

*** Mergen von ZA5305_Version4 und ZA5757_Version1

clear
set maxvar 30000
*cd "C:\"
use "ZA5305_v4-0-0.dta", clear
set more off, permanently


* Umbenennung der Variablennamen im WKP2009 zur eindeutigen Zuordnung
* Variablen aus ZA5305_Version4 beginnen mit Grobuchstaben bzw. KP-Kennung.
renvarlab kp1_split-kp7_jscript, upper
decode teilnahme, gen(Teilnahme)
rename version Version
rename study Study
rename field Field
rename year Year
rename glescomp Glescomp
rename w1 W1
rename w2 W2
rename w3 W3
rename w4 W4
rename w5 W5
rename w6 W6
rename w7 W7
rename mutant Mutant

* Merge-Variable: Laufende Nummer 2009
rename lfdn lfdn09
sort lfdn09
merge 1:1 lfdn09 using "ZA5757_v1-0-0.dta"

* Einmal Befragte und Doppeltbefragte
gen panel=1 if _merge==3
replace panel=0 if _merge!=3
lab def lpanel 1 "2009&2013" 0 "nur 2009"
lab val panel lpanel
drop _merge


save "wkp0913_all.dta", replace






*********************
*** Unterschiede zwischen Teilnehmern, die nur am WKP 2009 
*** teilgenommen haben, und jenen, die WKP 2013 wieder befragt wurden.

* Ausschluss von Panel-Mutanten 2009 (N=17)
drop if mut09==1


* Alter
ttest kpx_2290a, by(panel) unequal

* Wahlverhalten 2009
recode KP7_200B (4=2) (5=3) (6=4) (7=5)(1000=6), gen(btw09)
mvdecode btw09, mv(801 993 994 997 998 999 =.)
replace btw09=6 if KP7_180==2
label define lbtw09 1 "Union" 2 "SPD" 3 "FDP" 4 "Gruene" 5 "Linke" 6 "Nichtwahl"
lab val btw09 lbtw09
tab btw09 panel, col mis

* Bildung
gen abitur=1 if kpx_2320==5
replace abitur=0 if kpx_2320!=5 & kpx_2320!=9
ttest abitur, by(panel) unequal

* Politisches Interesse
recode KP2_010 (1=5) (2=4) (3=3) (4=2) (5=1) (99=.), gen(polint2)
recode KP4_010 (1=5) (2=4) (3=3) (4=2) (5=1) (99=.), gen(polint4)
recode KP6_010 (1=5) (2=4) (3=3) (4=2) (5=1) (99=.), gen(polint6)
recode KP7_010 (1=5) (2=4) (3=3) (4=2) (5=1) (99=.), gen(polint7)
egen ix_polint=rowmean (polint2 polint4 polint6 polint7)
replace ix_polint= (ix_polint-1)/4
lab var ix_polint "Index: Politisches Interesse"
lab define lpolint 1 "sehr stark interessiert" 0 "berhaupt nicht interessiert"
lab val ix_polint lpolint
ttest ix_polint, by(panel) unequal


**** Wellenteilnahmen im WKP 2009
encode Teilnahme, gen(teiln)
* mind. 3 Wellen
gen t3=0
replace t3=1 if teiln>2
* mind. 4 Wellen
gen t4=0
replace t4=1 if teiln>3
* alle 7 Wellen
gen t7=0
replace t7=1 if teiln==7


***** WKP 2009 ************

* PARTEIIDENTIFIKATION

* dummies
mvdecode KP1_2090, mv(999=.)
gen union_d1=0 if KP1_2090!=.
replace union_d1=1 if KP1_2090==2 | KP1_2090==3
gen spd_d1=0 if KP1_2090!=.
replace spd_d1=1 if KP1_2090==4
gen fdp_d1=0 if KP1_2090!=.
replace fdp_d1=1 if KP1_2090==5
gen gruen_d1=0 if KP1_2090!=.
replace gruen_d1=1 if KP1_2090==6
gen linke_d1=0 if KP1_2090!=.
replace linke_d1=1 if KP1_2090==7
gen nopid_d1=0 if KP1_2090!=.
replace nopid_d1=1 if KP1_2090==801


mvdecode KP3_2090, mv(999=.)
gen union_d3=0 if KP3_2090!=.
replace union_d3=1 if KP3_2090==2 | KP3_2090==3
gen spd_d3=0 if KP3_2090!=.
replace spd_d3=1 if KP3_2090==4
gen fdp_d3=0 if KP3_2090!=.
replace fdp_d3=1 if KP3_2090==5
gen gruen_d3=0 if KP3_2090!=.
replace gruen_d3=1 if KP3_2090==6
gen linke_d3=0 if KP3_2090!=.
replace linke_d3=1 if KP3_2090==7
gen nopid_d3=0 if KP3_2090!=.
replace nopid_d3=1 if KP3_2090==801

mvdecode KP5_2090, mv(999=.)
gen union_d5=0 if KP5_2090!=.
replace union_d5=1 if KP5_2090==2 | KP5_2090==3
gen spd_d5=0 if KP5_2090!=.
replace spd_d5=1 if KP5_2090==4
gen fdp_d5=0 if KP5_2090!=.
replace fdp_d5=1 if KP5_2090==5
gen gruen_d5=0 if KP5_2090!=.
replace gruen_d5=1 if KP5_2090==6
gen linke_d5=0 if KP5_2090!=.
replace linke_d5=1 if KP5_2090==7
gen nopid_d5=0 if KP5_2090!=.
replace nopid_d5=1 if KP5_2090==801


mvdecode KP7_2090, mv(999=.)
gen union_d7=0 if KP7_2090!=.
replace union_d7=1 if KP7_2090==2 | KP7_2090==3
gen spd_d7=0 if KP7_2090!=.
replace spd_d7=1 if KP7_2090==4
gen fdp_d7=0 if KP7_2090!=.
replace fdp_d7=1 if KP7_2090==5
gen gruen_d7=0 if KP7_2090!=.
replace gruen_d7=1 if KP7_2090==6
gen linke_d7=0 if KP7_2090!=.
replace linke_d7=1 if KP7_2090==7
gen nopid_d7=0 if KP7_2090!=.
replace nopid_d7=1 if KP7_2090==801


*** Strke der Parteibindung
recode KP1_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (99 100=.), gen(pidstaerke1)
recode KP3_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (99 100=.), gen(pidstaerke3)
recode KP5_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (99 100=.), gen(pidstaerke5)
recode KP7_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (99 100=.), gen(pidstaerke7)

recode kp1_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (-99 -97=.), gen(pidstaerke_1)
recode kp3_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (-99 -97 -95 -93=.), gen(pidstaerke_3)
recode kp5_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (-99 -97 -95 -93=.), gen(pidstaerke_5)
recode kp7_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (-99 -97 -95 -93=.), gen(pidstaerke_7)



* UNION
gen unionpid1=pidstaerke1 if union_d1==1
replace unionpid1=0 if union_d1==0
gen unionpid_1=pidstaerke_1 if union_d1==1
replace unionpid_1=0 if union_d1==0

gen unionpid3=pidstaerke3 if union_d3==1
replace unionpid3=0 if union_d3==0
gen unionpid_3=pidstaerke_3 if union_d3==1
replace unionpid_3=0 if union_d3==0

gen unionpid5=pidstaerke5 if union_d5==1
replace unionpid5=0 if union_d5==0
gen unionpid_5=pidstaerke_5 if union_d5==1
replace unionpid_5=0 if union_d5==0

gen unionpid7=pidstaerke7 if union_d7==1
replace unionpid7=0 if union_d7==0
gen unionpid_7=pidstaerke_7 if union_d7==1
replace unionpid_7=0 if union_d7==0

* CFA
*factor unionpid1 unionpid7 unionpid_1 unionpid_7
*rotate
*sem (Union_pid -> unionpid1 unionpid7 unionpid_1 unionpid_7), ///
	standardized latent(Union_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha unionpid1 unionpid7 unionpid_1 unionpid_7, item


* SPD
gen spdpid1=pidstaerke1 if spd_d1==1
replace spdpid1=0 if spd_d1==0
gen spdpid_1=pidstaerke_1 if spd_d1==1
replace spdpid_1=0 if spd_d1==0

gen spdpid3=pidstaerke3 if spd_d3==1
replace spdpid3=0 if spd_d3==0
gen spdpid_3=pidstaerke_3 if spd_d3==1
replace spdpid_3=0 if spd_d3==0

gen spdpid5=pidstaerke5 if spd_d5==1
replace spdpid5=0 if spd_d5==0
gen spdpid_5=pidstaerke_5 if spd_d5==1
replace spdpid_5=0 if spd_d5==0

gen spdpid7=pidstaerke7 if spd_d7==1
replace spdpid7=0 if spd_d7==0
gen spdpid_7=pidstaerke_7 if spd_d7==1
replace spdpid_7=0 if spd_d7==0

* CFA
*factor spdpid1 spdpid7 spdpid_1 spdpid_7
*rotate
*sem (SPD_pid -> spdpid1 spdpid7 spdpid_1 spdpid_7), ///
	standardized latent(SPD_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha spdpid1 spdpid7 spdpid_1 spdpid_7, item


* FDP
gen fdppid1=pidstaerke1 if fdp_d1==1
replace fdppid1=0 if fdp_d1==0
gen fdppid_1=pidstaerke_1 if fdp_d1==1
replace fdppid_1=0 if fdp_d1==0

gen fdppid3=pidstaerke3 if fdp_d3==1
replace fdppid3=0 if fdp_d3==0
gen fdppid_3=pidstaerke_3 if fdp_d3==1
replace fdppid_3=0 if fdp_d3==0

gen fdppid5=pidstaerke5 if fdp_d5==1
replace fdppid5=0 if fdp_d5==0
gen fdppid_5=pidstaerke_5 if fdp_d5==1
replace fdppid_5=0 if fdp_d5==0

gen fdppid7=pidstaerke7 if fdp_d7==1
replace fdppid7=0 if fdp_d7==0
gen fdppid_7=pidstaerke_7 if fdp_d7==1
replace fdppid_7=0 if fdp_d7==0

*CFA
*factor fdppid1 fdppid7 fdppid_1  fdppid_7
*rotate
*sem (FDP_pid -> fdppid1 fdppid7 fdppid_1 fdppid_7), ///
	standardized latent(FDP_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha fdppid1 fdppid7 fdppid_1 fdppid_7, item


* Grne
gen gruenpid1=pidstaerke1 if gruen_d1==1
replace gruenpid1=0 if gruen_d1==0
gen gruenpid_1=pidstaerke_1 if gruen_d1==1
replace gruenpid_1=0 if gruen_d1==0

gen gruenpid3=pidstaerke3 if gruen_d3==1
replace gruenpid3=0 if gruen_d3==0
gen gruenpid_3=pidstaerke_3 if gruen_d3==1
replace gruenpid_3=0 if gruen_d3==0

gen gruenpid5=pidstaerke5 if gruen_d5==1
replace gruenpid5=0 if gruen_d5==0
gen gruenpid_5=pidstaerke_5 if gruen_d5==1
replace gruenpid_5=0 if gruen_d5==0

gen gruenpid7=pidstaerke7 if gruen_d7==1
replace gruenpid7=0 if gruen_d7==0
gen gruenpid_7=pidstaerke_7 if gruen_d7==1
replace gruenpid_7=0 if gruen_d7==0

*CFA
*factor gruenpid1 gruenpid7 gruenpid_1  gruenpid_7
*rotate
*sem (Gruen_PID -> gruenpid1 gruenpid7 gruenpid_1 gruenpid_7), ///
	standardized latent(Gruen_PID) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha gruenpid1 gruenpid7 gruenpid_1 gruenpid_7, item



* Die Linke
gen linkepid1=pidstaerke1 if linke_d1==1
replace linkepid1=0 if linke_d1==0
gen linkepid_1=pidstaerke_1 if linke_d1==1
replace linkepid_1=0 if linke_d1==0

gen linkepid3=pidstaerke3 if linke_d3==1
replace linkepid3=0 if linke_d3==0
gen linkepid_3=pidstaerke_3 if linke_d3==1
replace linkepid_3=0 if linke_d3==0

gen linkepid5=pidstaerke5 if linke_d5==1
replace linkepid5=0 if linke_d5==0
gen linkepid_5=pidstaerke_5 if linke_d5==1
replace linkepid_5=0 if linke_d5==0

gen linkepid7=pidstaerke7 if linke_d7==1
replace linkepid7=0 if linke_d7==0
gen linkepid_7=pidstaerke_7 if linke_d7==1
replace linkepid_7=0 if linke_d7==0

* CFA
*factor linkepid1 linkepid7 linkepid_1 linkepid_7
*rotate
*sem (Linke_pid -> linkepid1 linkepid7 linkepid_1 linkepid_7), ///
	standardized latent(Linke_pid ) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha linkepid1 linkepid7 linkepid_1 linkepid_7, item



* Indices ber alle verfgbaren Wellen vor der BTW13
egen ix_unionpid=rowmean(unionpid1 unionpid3 unionpid5 unionpid7)
egen ix_spdpid=rowmean(spdpid1 spdpid3 spdpid5 spdpid7)
egen ix_fdppid=rowmean(fdppid1 fdppid3 fdppid5 fdppid7)
egen ix_gruenpid=rowmean(gruenpid1 gruenpid3 gruenpid5 gruenpid7)
egen ix_linkepid=rowmean(linkepid1 linkepid3 linkepid5 linkepid7)

replace ix_unionpid=ix_unionpid/5
replace ix_spdpid=ix_spdpid/5
replace ix_fdppid=ix_fdppid/5
replace ix_gruenpid=ix_gruenpid/5
replace ix_linkepid=ix_linkepid/5

lab var  ix_unionpid "Index: Strke der Union-Parteibindung"
lab var ix_spdpid "Index: Strke der SPD-Parteibindung"
lab var ix_fdppid "Index: Strke der FDP-Parteibindung"
lab var ix_gruenpid "Index: Strke der Grnen-Parteibindung"
lab var ix_linkepid "Index: Strke der Linke-Parteibindung"







***** SOZIOKONOMISCHE KONFLIKTDIMENSION

*** Einstellung: Zustimmung zu mehr Steuern und mehr Umverteilung
gen soceco1=(KP1_1090_11-1)/10 if KP1_1090_11<12
replace soceco1=((KP1_1090_7-1)/6) if KP1_1090_7<8
lab var soceco1 "mehr Steuern und mehr Umverteilung, W1"
label define lsocd1 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
label values soceco1 lsocd1

gen soceco7=(KP7_1090_7-1)/6 if KP7_1090_7<8
lab var soceco7 "mehr Steuern und mehr Umverteilung, W7"
label define lsocd7 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
label values soceco7 lsocd7



* Index fr die soziokonomische Dimension
egen ix_sozdim09 = rowmean(soceco1 soceco7)
lab var ix_sozdim09 "Index: soziokonomische Dimension wkp2009"
lab define lsdim09 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
lab val ix_sozdim09 lsdim09



*** Einstellung: Staat in Wirtschaft eingreifen
gen stama6=(KP6_1440_11-1)/10 if KP6_1440_11<12
replace stama6=((KP6_1440_7-1)/6) if KP6_1440_7<8
label define lstam 0 "Staat soll sich raushalten" 1 "Staat soll eingreifen"
label values stama6 lstam
label variable stama6 "Befrwortung: Staatseingriff in Wirtschaft"


*** Einstellung: Staat sollte mehr Schulden aufnehmen
gen schulden5=(KP5_1470_11-1)/10 if KP5_1470_11<12
replace schulden5=((KP5_1470_7-1)/6) if KP5_1470_7<8
label define lschulden 0 "weniger Schulden aufnehmen" 1 "mehr Schulden aufnehmen"
label values schulden5 lschulden
label variable schulden5 "Befrwortung: Schulden aufnehmen"



*** Verbundenheit mit EU
* wkp09
gen VerbundEU1=(KP1_2200D-1)/3 if KP1_2200D<5
gen VerbundEU5=(KP5_2200D-1)/3 if KP5_2200D<5
* Index fr die Verbundenheit mit der EU
egen ix_verbEU = rowmean(VerbundEU1 VerbundEU5)
lab var ix_verbEU "Index: Verbundenheit mit der EU 2009"
lab define lverEU 1 "stark verbunden" 0 "gar nicht verbunden"
lab val ix_verbEU lverEU


*** Verbundenheit mit Deutschland
gen VerbDeu1=(KP1_2200C-1)/3 if KP1_2200C<5
gen VerbDeu5=(KP5_2200C-1)/3 if KP5_2200C<5
* Index fr Verbundenheit mit Deutschland
egen ix_verbDeu=rowmean (VerbDeu1 VerbDeu5)
label define lvde 1 "stark verbunden" 0 "gar nicht verbunden"
label val ix_verbDeu lvde
lab var ix_verbDeu "Index: Verbundenheit mit Deutschland 2009"



***** KULTURELLE KONFLIKTDIMENSION

*** Einstellung: Auslnder sollen sich an deutsche Kultur anpassen
recode KP2_1210_11 (1=1) (2= .9) (3= .8) (4= .7) (5= .6) (6= .5) (7= .4) ///
	(8= .3) (9= .2) (10= .1) (11=0) if KP2_1210_11<12, gen(kultur2)
recode KP2_1210_7 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) if KP2_1210_7<8, gen(kultur2h)
replace kultur2=((kultur2h-1)/6)
lab var kultur2 "Auslnder sollen sich anpassen, W2"
label define lkul2 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur2 lkul2
drop kultur2h


recode KP5_1210_11 (1=1) (2= .9) (3= .8) (4= .7) (5= .6) (6= .5) (7= .4) ///
	(8= .3) (9= .2) (10= .1) (11=0) if KP5_1210_11<12, gen(kultur5)
recode KP5_1210_7 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) if KP5_1210_7<8, gen(kultur5h)
replace kultur5=((kultur5h-1)/6) if KP5_1210_11==. & W5==1
lab var kultur5 "Auslnder sollen sich anpassen, W5"
label define lkul5 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur5 lkul5
drop kultur5h


*** Einstellung: Zuzugsmglichkeit fr Auslnder einschrnken
gen zuzug1=(KP1_1130_11-1)/10 if KP1_1130_11<12
replace zuzug1=((KP1_1130_7-1)/6) if KP1_1130_7<8
lab var zuzug1 "Zuzug von Auslndern einschrnken, W1"
label define lzuzug1 1 "Zuzug einschrnken" ///
	0 "Zuzug erleichtern"
label values zuzug1 lzuzug1 

gen zuzug7=(KP7_1130_11-1)/10 if KP7_1130_11<12
replace zuzug7=((KP7_1130_7-1)/6) if KP7_1130_7<8
lab var zuzug7 "Zuzug von Auslndern einschrnken, W7"
label define lzuzug7 1 "Zuzug einschrnken" ///
	0 "Zuzug erleichtern"
label values zuzug7 lzuzug7


* Index fr kulturelle Dimension
egen ix_kultdim09 = rowmean(kultur2 kultur5 zuzug1 zuzug7)
lab var ix_kultdim09 "Index: kulturelle Dimension"
lab define lkultdim 0 "fr kulturelle Vielfalt" 1 "gegen kulturelle Vielfalt"
lab val ix_kultdim09 lkultdim




*** Merkel Skalometer
* 2009
gen Merkel1=(KP1_650A-1)/10 if KP1_650A<12
gen Merkel2=(KP2_650A-1)/10 if KP2_650A<12
gen Merkel3=(KP3_650A-1)/10 if KP3_650A<12
gen Merkel4=(KP4_650A-1)/10 if KP4_650A<12
gen Merkel5=(KP5_650A-1)/10 if KP5_650A<12
gen Merkel6=(KP6_650A-1)/10 if KP6_650A<12
gen Merkel7=(KP7_650A-1)/10 if KP7_650A<12
* Index fr Merkel
egen ix_merkel=rowmean(Merkel1 Merkel2 Merkel3 Merkel4 Merkel5 Merkel6 Merkel7) 
lab var ix_merkel "Index: Sympathie mit Merkel wkp 2009"



* Steinbrck Skalometer
*2009
gen Steinb3=(KP3_650K-1)/10 if KP3_650K<12
gen Steinb6=(KP6_650K-1)/10 if KP6_650K<12
* Index fr Steinbrck
egen ix_steinb=rowmean(Steinb3 Steinb6) 
lab var ix_steinb "Index: Sympathie mit Steinbrck wkp 2009"

* Index fr Schuble
gen schub3=(KP3_650M-1)/10 if KP3_650M<12
gen schub6=(KP6_650M-1)/10 if KP6_650M<12
egen ix_schub=rowmean(schub3 schub6) 
lab var ix_schub "Index: Sympathie mit Schuble wkp 2009"

sum ix_merkel ix_steinb ix_schub




ttest ix_kultdim09, by(panel) unequal
ttest ix_sozdim09, by(panel) unequal
ttest ix_merkel, by(panel) unequal
ttest ix_steinb, by(panel) unequal
ttest ix_schub, by(panel) unequal
ttest ix_verbEU, by(panel) unequal
ttest ix_verbDeu, by(panel) unequal


ttest ix_polint, by(t3) unequal
ttest ix_polint, by(t4) unequal
ttest ix_polint, by(t7) unequal
ttest abitur, by(t3) unequal
ttest abitur, by(t4) unequal
ttest abitur, by(t7) unequal
ttest kpx_2290a, by(t3) unequal
ttest kpx_2290a, by(t4) unequal
ttest kpx_2290a, by(t7) unequal
tab btw09 t3, col
tab btw09 t4, col
tab btw09 t7, col
* Politisch interessierter, lter, hher gebildet, t3: eher Nichtwhler

* ix_kultdim09 fr mehr kult Vielfalt
ttest ix_kultdim09, by(t3) unequal
ttest ix_kultdim09, by(t4) unequal
ttest ix_kultdim09, by(t7) unequal
* ix_sozdim09 fr mehr Umverteilung
ttest ix_sozdim09, by(t3) unequal
ttest ix_sozdim09, by(t4) unequal
ttest ix_sozdim09, by(t7) unequal
* ix_merkel n.s.
ttest ix_merkel, by(t3) unequal
ttest ix_merkel, by(t4) unequal
ttest ix_merkel, by(t7) unequal
* ix_steinb t3 und t4 Steinbrck positiver
ttest ix_steinb, by(t3) unequal
ttest ix_steinb, by(t4) unequal
ttest ix_steinb, by(t7) unequal
* ix_schub n.s.
ttest ix_schub, by(t3) unequal
ttest ix_schub, by(t4) unequal
ttest ix_schub, by(t7) unequal
* ix_verbEU n.s.
ttest ix_verbEU, by(t3) unequal
ttest ix_verbEU, by(t4) unequal
ttest ix_verbEU, by(t7) unequal
* ix_verbDeu n.s.
ttest ix_verbDeu, by(t3) unequal
ttest ix_verbDeu, by(t4) unequal
ttest ix_verbDeu, by(t7) unequal


*** Stabilitt der Strke der Parteiidentifikation
alpha unionpid1 unionpid3 unionpid5 unionpid7 if panel==1, item
alpha unionpid1 unionpid3 unionpid5 unionpid7 if panel==0, item
alpha spdpid1 spdpid3 spdpid5 spdpid7 if panel==1, item
alpha spdpid1 spdpid3 spdpid5 spdpid7 if panel==0, item
alpha fdppid1 fdppid3 fdppid5 fdppid7 if panel==1, item
alpha fdppid1 fdppid3 fdppid5 fdppid7 if panel==0, item
alpha gruenpid1 gruenpid3 gruenpid5 gruenpid7 if panel==1, item
alpha gruenpid1 gruenpid3 gruenpid5 gruenpid7 if panel==0, item
alpha linkepid1 linkepid3 linkepid5 linkepid7 if panel==1, item
alpha linkepid1 linkepid3 linkepid5 linkepid7 if panel==0, item
alpha soceco1 soceco7 if panel==1, item
alpha soceco1 soceco7 if panel==0, item
alpha kultur2 kultur5 zuzug1 zuzug7 if panel==1, item
alpha kultur2 kultur5 zuzug1 zuzug7 if panel==0, item
alpha VerbundEU1 VerbundEU5 if panel==1, item
alpha VerbundEU1 VerbundEU5 if panel==0, item
alpha VerbDeu1 VerbDeu5 if panel==1, item
alpha VerbDeu1 VerbDeu5 if panel==0, item
alpha Merkel1 Merkel2 Merkel3 Merkel4 Merkel5 Merkel6 Merkel7 if panel==1, item
alpha Merkel1 Merkel2 Merkel3 Merkel4 Merkel5 Merkel6 Merkel7 if panel==0, item
alpha Steinb3 Steinb6 if panel==1, item
alpha Steinb3 Steinb6 if panel==0, item
alpha schub3 schub6 if panel==1, item
alpha schub3 schub6 if panel==0, item



****************************************************************************************
****************************************************************************************
****************************************************************************************
****************************************************************************************
****************************************************************************************
****************************************************************************************

clear
use "wkp0913_all.dta", clear
set more off, permanently

*** Nur Variablen aus dem ZA5757-Datensatz
sort lfdn09
keep lfdn09 lfdn-panel
*** Nur Befragte, die 2009 und 2013 teilgenommen haben.
keep if panel==1
*** Ausschluss von Panel-Mutanten 2009 (N=17)
drop if mut09==1


*** Definition der fehlenden Werte

foreach var of varlist _all {
	capture confirm numeric var `var'
	if !_rc {
		mvdecode `var', mv(-71=.p \-72=.o \-81=.n \-82=.m \-83=.l ///
				 \-84=.k \-85=.j \-86=.i \-92=.h \-93=.g ///
				 \-94=.f \-95=.e \-96=.d \-97=.c \-98=.b ///
				 \-99=.a)
				 
	label define `var' ///
		.a"keine Angabe" ///
		.b"weiss nicht" ///
		.c"trifft nicht zu" ///
		.d"Split" ///
		.e"nicht teilgenommen" ///
		.f"nicht in Auswahlgesamtheit" ///
		.g"Interview abgebrochen" ///
		.h"Fehler in Daten" ///
		.i"nicht wahlberechtigt" ///
		.j"nicht waehlen" ///
		.k"keine Erst-/Zweitstimme abgegeben" ///
		.l"ungueltig waehlen" ///
		.m"keine andere Partei waehlen" ///
		.n"noch nicht entschieden" ///
		.o"nicht einzuschaetzen" ///
		.p"nicht bekannt", modify
		}
	else {
		replace `var'=".a keine Angabe" if `var'=="-99 keine Angabe"
		replace `var'=".c trifft nicht zu" if `var'=="-97 trifft nicht zu"
		replace `var'=".e nicht teilgenommen" if `var'=="-95 nicht teilgenommen"
		replace `var'=".g Interview abgebrochen" if `var'=="-93 Interview abgebrochen"
		}
}


*


****************************************
*** Wahlentscheidung Zweitstimme
recode kp14_200ba (4=2) (5=3) (6=4) (7=5) (801=.), gen(btw13)
replace btw13=6 if kp14_200bb==322
replace btw13=7 if kp14_180==2
label define lbtw 1 "Union" 2 "SPD" 3 "FDP" 4 "Gruene" 5 "Linke" 6 "AfD" ///
		7 "Nichtwahl"
label values btw13 lbtw
label variable btw13 "BTW Zweitstimme"


tab btw13, gen(partei)
rename partei1 UNION
lab var UNION "BTW13: Union"
rename partei2 SPD
lab var SPD "BTW13: SPD"
rename partei3 FDP
lab var FDP "BTW13: FDP"
rename partei4 GRUEN
lab var GRUEN "BTW13: Grne"
rename partei5 LINKE
lab var LINKE "BTW13: Linke"
rename partei6 AFD
lab var AFD "BTW13: AfD"
rename partei7 NICHTWAHL
lab var NICHTWAHL "BTW13: Nichtwahl"


***** PERFORMANZ SCHULDENKRISE
	
*** Performanz BReg (Welle 3 und 7)
recode kp10_3060 (1=5) (2=4) (3=3) (4=2) (5=1), gen(BRegPerf3)
replace BRegPerf3=(BRegPerf3-1)/4
label define lBRegPerf3 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values BRegPerf3 lBRegPerf3

recode kp14_3060 (1=5) (2=4) (3=3) (4=2) (5=1), gen(BRegPerf7)
replace BRegPerf7=(BRegPerf7-1)/4
label define lBRegPerf7 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values BRegPerf7 lBRegPerf7

*** Performanz Merkel (Welle 3, 5 und 7)
recode kp10_3070a (1=5) (2=4) (3=3) (4=2) (5=1), gen(MerkelPerf3)
replace MerkelPerf3=(MerkelPerf3-1)/4
label define lMerkelPerf3 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values MerkelPerf3 lMerkelPerf3

recode kp12_3070a (1=5) (2=4) (3=3) (4=2) (5=1), gen(MerkelPerf5)
replace MerkelPerf5=(MerkelPerf5-1)/4
label define lMerkelPerf5 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values MerkelPerf5 lMerkelPerf5

recode kp14_3070a (1=5) (2=4) (3=3) (4=2) (5=1), gen(MerkelPerf7)
replace MerkelPerf7=(MerkelPerf7-1)/4
label define lMerkelPerf7 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values MerkelPerf7 lMerkelPerf7




*** Performanz Steinbrck (Welle 3, 5 und 7)
recode kp10_3070b (1=5) (2=4) (3=3) (4=2) (5=1), gen(SteinbPerf3)
replace SteinbPerf3=(SteinbPerf3-1)/4
label define lSteinbPerf3 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values SteinbPerf3 lSteinbPerf3

recode kp12_3070b (1=5) (2=4) (3=3) (4=2) (5=1), gen(SteinbPerf5)
replace SteinbPerf5=(SteinbPerf5-1)/4
label define lSteinbPerf5 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values SteinbPerf5 lSteinbPerf5

recode kp14_3070b (1=5) (2=4) (3=3) (4=2) (5=1), gen(SteinbPerf7)
replace SteinbPerf7=(SteinbPerf7-1)/4
label define lSteinbPerf7 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values SteinbPerf7 lSteinbPerf7





***** EINSTELLUNG ZU EUROPISCHEN HILFEN

*** Prferenz EU-Hilfe Ego (Welle 3, 5 und 7)
recode kp10_2830 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), gen(Prfego3)
replace Prfego3=(Prfego3-1)/6
label define lPrfe3 0 "gegen die Beteiligung Deutschlands" ///
	1 "fr die Beteiligung Deutschlands"
label values Prfego3 lPrfe3


recode kp12_2830 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), gen(Prfego5)
replace Prfego5=(Prfego5-1)/6
label define lPrfe5 0 "gegen die Beteiligung Deutschlands" ///
	1 "fr die Beteiligung Deutschlands"
label values Prfego5 lPrfe5


recode kp14_2830 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), gen(Prfego7)
replace Prfego7=(Prfego7-1)/6
label define lPrfe7 0 "gegen die Beteiligung Deutschlands" ///
	1 "fr die Beteiligung Deutschlands"
label values Prfego7 lPrfe7







***** WKP 2009 ************

* PARTEIIDENTIFIKATION


*** Strke der Parteibindung
recode kp1_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.c .e=.), gen(pidstaerke1)
recode kp3_2100 (1=5) (2=4) (3=3) (4=2) (5=1)(.a .c .e=.), gen(pidstaerke3)
recode kp5_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c .e=.), gen(pidstaerke5)
recode kp7_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c .e=.), gen(pidstaerke7)
recode kp8_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c=.), gen(pidstaerke8)
recode kp10_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c .e .g=.), gen(pidstaerke10)
recode kp12_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c .e .g=.), gen(pidstaerke12)
recode kp14_2100 (1=5) (2=4) (3=3) (4=2) (5=1) (.a .c .e .g=.), gen(pidstaerke14)

* UNION
gen unionpid1=0
replace unionpid1=pidstaerke1 if kp1_2090a==2 | kp1_2090a==3
replace unionpid1=. if kp1_2090a==.a | kp1_2090a==.e

gen unionpid3=0
replace unionpid3=pidstaerke3 if kp3_2090a==2 | kp3_2090a==3
replace unionpid3=. if kp3_2090a==.a | kp3_2090a==.e

gen unionpid5=0
replace unionpid5=pidstaerke5 if kp5_2090a==2 | kp5_2090a==3
replace unionpid5=. if kp5_2090a==.a | kp5_2090a==.e

gen unionpid7=0
replace unionpid7=pidstaerke7 if kp7_2090a==2 | kp7_2090a==3
replace unionpid7=. if kp7_2090a==.a | kp7_2090a==.e

gen unionpid8=0
replace unionpid8=pidstaerke8 if kp8_2090a==2 | kp8_2090a==3
replace unionpid8=. if kp8_2090a==.a

gen unionpid10=0
replace unionpid10=pidstaerke10 if kp10_2090a==2 | kp10_2090a==3
replace unionpid10=. if kp10_2090a==.a | kp10_2090a==.e | kp10_2090a==.g

gen unionpid12=0
replace unionpid12=pidstaerke12 if kp12_2090a==2 | kp12_2090a==3
replace unionpid12=. if kp12_2090a==.a | kp12_2090a==.e | kp12_2090a==.g

gen unionpid14=0
replace unionpid14=pidstaerke14 if kp14_2090a==2 | kp14_2090a==3
replace unionpid14=. if kp14_2090a==.a | kp14_2090a==.e | kp14_2090a==.g


* CFA
*factor unionpid1 unionpid7 unionpid8 unionpid14
*rotate
*sem (Union_pid -> unionpid1 unionpid7 unionpid8 unionpid14), ///
	standardized latent(Union_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha unionpid1 unionpid7 unionpid8 unionpid14, item


* SPD
gen spdpid1=0
replace spdpid1=pidstaerke1 if kp1_2090a==4
replace spdpid1=. if kp1_2090a==.a | kp1_2090a==.e

gen spdpid3=0
replace spdpid3=pidstaerke3 if kp3_2090a==4
replace spdpid3=. if kp3_2090a==.a | kp3_2090a==.e

gen spdpid5=0
replace spdpid5=pidstaerke5 if kp5_2090a==4
replace spdpid5=. if kp5_2090a==.a | kp5_2090a==.e

gen spdpid7=0 
replace spdpid7=pidstaerke7 if kp7_2090a==4
replace spdpid7=. if kp7_2090a==.a | kp7_2090a==.e

gen spdpid8=0
replace spdpid8=pidstaerke8 if kp8_2090a==4
replace spdpid8=. if kp8_2090a==.a

gen spdpid10=0
replace spdpid10=pidstaerke10 if kp10_2090a==4
replace spdpid10=. if kp10_2090a==.a | kp10_2090a==.e | kp10_2090a==.g

gen spdpid12=0
replace spdpid12=pidstaerke12 if kp12_2090a==4
replace spdpid12=. if kp12_2090a==.a | kp12_2090a==.e | kp12_2090a==.g

gen spdpid14=0
replace spdpid14=pidstaerke14 if kp14_2090a==4
replace spdpid14=. if kp14_2090a==.a | kp14_2090a==.e | kp14_2090a==.g



* CFA
*factor spdpid1 spdpid7 spdpid8 spdpid14
*rotate
*sem (SPD_pid -> spdpid1 spdpid7 spdpid8 spdpid14), ///
	standardized latent(SPD_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha spdpid1 spdpid7 spdpid8 spdpid14, item


* FDP
gen fdppid1=0
replace fdppid1=pidstaerke1 if kp1_2090a==5
replace fdppid1=. if kp1_2090a==.a | kp1_2090a==.e

gen fdppid3=0
replace fdppid3=pidstaerke3 if kp3_2090a==5
replace fdppid3=. if kp3_2090a==.a | kp3_2090a==.e

gen fdppid5=0
replace fdppid5=pidstaerke5 if kp5_2090a==5
replace fdppid5=. if kp5_2090a==.a | kp5_2090a==.e

gen fdppid7=0
replace fdppid7=pidstaerke7 if kp7_2090a==5
replace fdppid7=. if kp7_2090a==.a | kp7_2090a==.e

gen fdppid8=0
replace fdppid8=pidstaerke8 if kp8_2090a==5
replace fdppid8=. if kp8_2090a==.a

gen fdppid10=0
replace fdppid10=pidstaerke10 if kp10_2090a==5
replace fdppid10=. if kp10_2090a==.a | kp10_2090a==.e | kp10_2090a==.g

gen fdppid12=0
replace fdppid12=pidstaerke12 if kp12_2090a==5
replace fdppid12=. if kp12_2090a==.a | kp12_2090a==.e | kp12_2090a==.g

gen fdppid14=0
replace fdppid14=pidstaerke14 if kp14_2090a==5
replace fdppid14=. if kp14_2090a==.a | kp14_2090a==.e | kp14_2090a==.g




*CFA
*factor fdppid1 fdppid7 fdppid8  fdppid14
*rotate
sem (FDP_pid -> fdppid1 fdppid7 fdppid8  fdppid14), ///
	standardized latent(FDP_pid) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha fdppid1 fdppid7 fdppid8  fdppid14, item


* Grne
gen gruenpid1=0
replace gruenpid1=pidstaerke1 if kp1_2090a==6
replace gruenpid1=. if kp1_2090a==.a | kp1_2090a==.e

gen gruenpid3=0
replace gruenpid3=pidstaerke3 if kp3_2090a==6
replace gruenpid3=. if kp3_2090a==.a | kp3_2090a==.e

gen gruenpid5=0
replace gruenpid5=pidstaerke5 if kp5_2090a==6
replace gruenpid5=. if kp5_2090a==.a | kp5_2090a==.e

gen gruenpid7=0
replace gruenpid7=pidstaerke7 if kp7_2090a==6
replace gruenpid7=. if kp7_2090a==.a | kp7_2090a==.e

gen gruenpid8=0
replace gruenpid8=pidstaerke8 if kp8_2090a==6
replace gruenpid8=. if kp8_2090a==.a

gen gruenpid10=0
replace gruenpid10=pidstaerke10 if kp10_2090a==6
replace gruenpid10=. if kp10_2090a==.a | kp10_2090a==.e | kp10_2090a==.g

gen gruenpid12=0
replace gruenpid12=pidstaerke12 if kp12_2090a==6
replace gruenpid12=. if kp12_2090a==.a | kp12_2090a==.e | kp12_2090a==.g

gen gruenpid14=0
replace gruenpid14=pidstaerke14 if kp14_2090a==6 
replace gruenpid14=. if kp14_2090a==.a | kp14_2090a==.e | kp14_2090a==.g



*CFA
*factor gruenpid1 gruenpid7 gruenpid8 gruenpid14
*rotate
*sem (Gruen_PID -> gruenpid1 gruenpid7 gruenpid8 gruenpid14), ///
	standardized latent(Gruen_PID) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha gruenpid1 gruenpid7 gruenpid8 gruenpid14, item



* Die Linke
gen linkepid1=0
replace linkepid1=pidstaerke1 if kp1_2090a==7
replace linkepid1=. if kp1_2090a==.a | kp1_2090a==.e

gen linkepid3=0
replace linkepid3=pidstaerke3 if kp3_2090a==7
replace linkepid3=. if kp3_2090a==.a | kp3_2090a==.e

gen linkepid5=0
replace linkepid5=pidstaerke5 if kp5_2090a==7
replace linkepid5=. if kp5_2090a==.a | kp5_2090a==.e

gen linkepid7=0
replace linkepid7=pidstaerke7 if kp7_2090a==7
replace linkepid7=. if kp7_2090a==.a | kp7_2090a==.e

gen linkepid8=0
replace linkepid8=pidstaerke8 if kp8_2090a==7
replace linkepid8=. if kp8_2090a==.a

gen linkepid10=0
replace linkepid10=pidstaerke10 if kp10_2090a==7
replace linkepid10=. if kp10_2090a==.a | kp10_2090a==.e | kp10_2090a==.g

gen linkepid12=0
replace linkepid12=pidstaerke12 if kp12_2090a==7
replace linkepid12=. if kp12_2090a==.a | kp12_2090a==.e | kp12_2090a==.g

gen linkepid14=0
replace linkepid14=pidstaerke14 if kp14_2090a==7
replace linkepid14=. if kp14_2090a==.a | kp14_2090a==.e | kp14_2090a==.g



* CFA
*factor linkepid1 linkepid7 linkepid8 linkepid14
*rotate
*sem (Linke_pid -> linkepid1 linkepid7 linkepid8 linkepid14), ///
	standardized latent(Linke_pid ) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha linkepid1 linkepid7 linkepid8 linkepid14, item



* Indices ber alle verfgbaren Wellen im wkp2009
egen ix_unionpid=rowmean(unionpid1 unionpid3 unionpid5 unionpid7)
egen ix_spdpid=rowmean(spdpid1 spdpid3 spdpid5 spdpid7)
egen ix_fdppid=rowmean(fdppid1 fdppid3 fdppid5 fdppid7)
egen ix_gruenpid=rowmean(gruenpid1 gruenpid3 gruenpid5 gruenpid7)
egen ix_linkepid=rowmean(linkepid1 linkepid3 linkepid5 linkepid7)

replace ix_unionpid=ix_unionpid/5
replace ix_spdpid=ix_spdpid/5
replace ix_fdppid=ix_fdppid/5
replace ix_gruenpid=ix_gruenpid/5
replace ix_linkepid=ix_linkepid/5

lab var  ix_unionpid "Index: Strke der Union-Parteibindung"
lab var ix_spdpid "Index: Strke der SPD-Parteibindung"
lab var ix_fdppid "Index: Strke der FDP-Parteibindung"
lab var ix_gruenpid "Index: Strke der Grnen-Parteibindung"
lab var ix_linkepid "Index: Strke der Linke-Parteibindung"







***** SOZIOKONOMISCHE KONFLIKTDIMENSION

*** Einstellung: Zustimmung zu mehr Steuern und mehr Umverteilung
gen soceco1=(kp1_1090-1)/6 if kp1_1090<11
replace soceco1=(kp1_1090-11)/10 if kp1_1090>10 & kp1_1090!=.a & kp1_1090!=.b & kp1_1090!=.e
lab var soceco1 "mehr Steuern und mehr Umverteilung"
label define lsocd1 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
label values soceco1 lsocd1

gen soceco7=(kp7_1090-1)/6 if kp7_1090<11
replace soceco7=(kp7_1090-11)/10 if kp7_1090>10 & kp7_1090!=.a & kp7_1090!=.b & kp7_1090!=.e
lab var soceco7 "mehr Steuern und mehr Umverteilung"
label define lsocd7 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
label values soceco7 lsocd7


gen soceco8=(kp8_1090-1)/6
gen soceco9=(kp9_1090-1)/6
gen soceco10=(kp10_1090-1)/6
gen soceco11=(kp11_1090-1)/6
gen soceco12=(kp12_1090-1)/6
gen soceco13=(kp13_1090-1)/6
gen soceco14=(kp14_1090-1)/6

* CFA
*factor soceco1 soceco7 soceco8 soceco14
*rotate
*sem (SocEcoDim -> soceco1 soceco7 soceco8 soceco14), ///
	standardized latent(SocEcoDim) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha soceco1 soceco7 soceco8 soceco14, item


* Index fr die soziokonomische Dimension
egen ix_sozdim09 = rowmean(soceco1 soceco7)
egen ix_sozdim13 = rowmean(soceco8 soceco9 soceco10 soceco11 soceco12 soceco13)
lab var ix_sozdim09 "Index: soziokonomische Dimension wkp2009"
lab define lsdim09 1 "mehr Steuern mehr Umverteilung" 0 "weniger Steuern weniger Umverteilung"
lab val ix_sozdim09 lsdim09
lab var ix_sozdim13 "Index: soziokonomische Dimension wkp2013" 



*** Einstellung: Staat in Wirtschaft eingreifen
gen stama6=(kp6_1440-1)/6 if kp6_1440<10
replace stama6=((kp6_1440-11)/10) if kp6_1440>10 & kp6_1440!=.a & kp6_1440!=.b & kp6_1440!=.e
label define lstama 0 "Staat soll sich raushalten" 1 "Staat soll eingreifen"
label values stama6 lstama
label variable stama6 "Befrwortung: Staatseingriff in Wirtschaft"




*** Einstellung: Staat sollte mehr Schulden aufnehmen
gen schulden5=(kp5_1470-1)/6 if kp5_1470<10
replace schulden5=((kp5_1470-11)/10) if kp5_1470>10 & kp5_1470!=.a & kp5_1470!=.b & kp5_1470!=.d & kp5_1470!=.e
label define lschulden 0 "weniger Schulden aufnehmen" 1 "mehr Schulden aufnehmen"
label values schulden5 lschulden
label variable schulden5 "Befrwortung: Schulden aufnehmen"


*** Einstellung: Kosten fr Finanzkrise bleiben beim Steuerzahler hngen
* Anmerkung: Wertelabel im Originaldatensatz falsch
gen kostkrise4=(kp4_2730h-1)/4
label define lkost 0 "trifft berhaupt nicht zu" 1 "trifft voll und ganz zu"
label values kostkrise4 lkost
label variable kostkrise4 "Steuerzahler zahlt Krisenkosten"
* Hat mglicherweise einen strkeren Bezug der weltweiten Finanz- und 
* Wirtschaftskrise 2009.




*** Verbundenheit mit EU
* wkp09
gen VerbundEU1=(kp1_2200d-1)/3 if kp1_2200d!=.a & kp1_2200d!=.e
gen VerbundEU5=(kp5_2200d-1)/3 if kp5_2200d!=.a & kp5_2200d!=.e
* wkp13
gen VerbundEU10=(kp10_2200d-11)/4 if kp10_2200d!=.a & kp10_2200d!=.e & kp10_2200d!=.g
* wkp13: 5 Ausprgungen und wkp09: 4 Ausprgungen!

* CFA
*factor VerbundEU1 VerbundEU5 VerbundEU10
*rotate
*sem (TerrIdentitt -> VerbundEU1 VerbundEU5 VerbundEU10), ///
	standardized latent(TerrIdentittEU) nocapslatent 
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha VerbundEU1 VerbundEU5 VerbundEU10, item

* Index fr die Verbundenheit mit der EU
egen ix_verbEU = rowmean(VerbundEU1 VerbundEU5)
lab var ix_verbEU "Index: Verbundenheit mit der EU 2009"
lab define lverEU 1 "stark verbunden" 0 "gar nicht verbunden"
lab val ix_verbEU lverEU




*** Verbundenheit mit Deutschland
gen VerbDeu1=(kp1_2200c-1)/3 if kp1_2200c!=.a & kp1_2200c!=.e
gen VerbDeu5=(kp5_2200c-1)/3 if kp5_2200c!=.a & kp5_2200c!=.e
* wkp13
gen VerbDeu10=(kp10_2200c-11)/4 if kp10_2200c!=.a & kp10_2200c!=.e & kp10_2200c!=.g
* wkp13: 5 Ausprgungen und wkp09: 4 Ausprgungen!

* CFA
*factor VerbDeu1 VerbDeu5 VerbDeu10
*rotate
*sem (TerrIdentitt -> VerbDeu1 VerbDeu5 VerbDeu10), ///
	standardized latent(TerrIdentittD) nocapslatent 
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha VerbDeu1 VerbDeu5 VerbDeu10, item

* Index fr Verbundenheit mit Deutschland
egen ix_verbDeu=rowmean (VerbDeu1 VerbDeu5)
label define lvde 1 "stark verbunden" 0 "gar nicht verbunden"
label val ix_verbDeu lvde
lab var ix_verbDeu "Index: Verbundenheit mit Deutschland 2009"



***** KULTURELLE KONFLIKTDIMENSION

*** Einstellung: Auslnder sollen sich an deutsche Kultur anpassen
recode kp2_1210 (11=1) (12= .9) (13= .8) (14= .7) (15= .6) (16= .5) (17= .4) ///
	(18= .3) (19= .2) (20= .1) (21=0) (.a .b .e=.) if kp2_1210>10 , gen(kultur2)
recode kp2_1210 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) (.a .b .e=.) if kp2_1210<10, gen(kultur2h)
replace kultur2=((kultur2h-1)/6) if kultur2==. & kp2_1210!=.a & kp2_1210!=.b & kp2_1210!=.e
lab var kultur2 "Auslnder sollen sich anpassen, W2"
label define lkul2 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur2 lkul2
drop kultur2h


recode kp5_1210 (11=1) (12= .9) (13= .8) (14= .7) (15= .6) (16= .5) (17= .4) ///
	(18= .3) (19= .2) (20= .1) (21=0) (.a .b .e=.) if kp5_1210>10, gen(kultur5)
recode kp5_1210 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) (.a .b .e=.) if kp5_1210<10, gen(kultur5h)
replace kultur5=((kultur5h-1)/6) if kultur5==. & kp5_1210!=.a & kp5_1210!=.b & kp5_1210!=.e
lab var kultur5 "Auslnder sollen sich anpassen, W5"
label define lkul5 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur5 lkul5
drop kultur5h




* wkp 2013
recode kp10_1210 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) (.a .e .g=.), gen(kultur10)
replace kultur10 = (kultur10-1)/6
lab var kultur10 "Auslnder sollen sich anpassen, W3 wkp 2013"
label define lkul10 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur10 lkul10

recode kp13_1210 (1=7) (2=6) (3=5) (4=4) (5=3) ///
	(6=2) (7=1) (.a .b .e=.), gen(kultur13)
replace kultur13 = (kultur13-1)/6
lab var kultur13 "Auslnder sollen sich anpassen, W13"
label define lkul13 1 "sollen sich vollstndig anpassen" ///
	0 "sollen mglichst nach eigener Kultur leben"
label values kultur13 lkul13



*** Einstellung: Zuzugsmglichkeit fr Auslnder einschrnken
gen zuzug1=(kp1_1130-11)/10 if kp1_1130>10
replace zuzug1=((kp1_1130-1)/6) if kp1_1130<10 & kp1_1130!=.a & kp1_1130!=.b & kp1_1130!=.e
lab var zuzug1 "Zuzug von Auslndern einschrnken, W1"
label define lzuzug1 1 "Zuzug einschrnken" ///
	0 "Zuzug erleichtern"
label values zuzug1 lzuzug1


gen zuzug7=(kp7_1130-11)/10 if kp7_1130>10
replace zuzug7=((kp7_1130-1)/6) if kp7_1130<10 & kp7_1130!=.a & kp7_1130!=.b & kp7_1130!=.e
lab var zuzug7 "Zuzug von Auslndern einschrnken, W7"
label define lzuzug7 1 "Zuzug einschrnken" ///
	0 "Zuzug erleichtern"
label values zuzug7 lzuzug7 





* wkp 2013
gen zuzug8=(kp8_1130-1)/6
lab var zuzug8 "Zuzug von Auslndern einschrnken, W8"
label define lzuzug8 1 "Zuzug einschrnken" 0 "Zuzug erleichtern"
label values zuzug8 lzuzug8

gen zuzug11=(kp11_1130-1)/6
lab var zuzug11 "Zuzug von Auslndern einschrnken, W11"
label define lzuzug11 1 "Zuzug einschrnken" 0 "Zuzug erleichtern"
label values zuzug11 lzuzug11

gen zuzug14=(kp14_1130-1)/6
lab var zuzug14 "Zuzug von Auslndern einschrnken, W14"
label define lzuzug14 1 "Zuzug einschrnken" 0 "Zuzug erleichtern"
label values zuzug14 lzuzug14


* CFA
*factor kultur2 kultur5 kultur10 kultur13 zuzug1 zuzug7 zuzug8 zuzug14
*rotate
*sem (KultDim -> kultur2 kultur5 kultur10 kultur13 zuzug1 zuzug7 zuzug8 zuzug14), ///
	standardized latent(KultDim ) cov(e.kultur10*e.kultur13 e.kultur2*e.kultur5 ///
	e.zuzug1*e.zuzug7 e.zuzug8*e.zuzug14) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha kultur2 kultur5 kultur10 kultur13 zuzug1 zuzug7 zuzug8 zuzug14, item

* CFA
*sem (KultDim -> kultur2 kultur10 zuzug1 zuzug8), ///
	standardized latent(KultDim) nocapslatent
*estat gof, stat(all)
*estat mindices
*alpha kultur2 kultur10 zuzug1 zuzug8, item

* Index fr kulturelle Dimension
egen ix_kultdim09 = rowmean(kultur2 kultur5 zuzug1 zuzug7)
lab var ix_kultdim09 "Index: kulturelle Dimension"
lab define lkultdim 0 "fr kulturelle Vielfalt" 1 "gegen kulturelle Vielfalt"
lab val ix_kultdim09 lkultdim




*** Merkel Skalometer
* 2009
gen Merkel1=(kp1_650a-1)/10
gen Merkel2=(kp2_650a-1)/10
gen Merkel3=(kp3_650a-1)/10
gen Merkel4=(kp4_650a-1)/10
gen Merkel5=(kp5_650a-1)/10
gen Merkel6=(kp6_650a-1)/10
gen Merkel7=(kp7_650a-1)/10
* 2013
gen Merkel8=(kp8_650a-1)/10
gen Merkel9=(kp9_650a-1)/10
gen Merkel10=(kp10_650a-1)/10
gen Merkel11=(kp11_650a-1)/10
gen Merkel12=(kp12_650a-1)/10
gen Merkel13=(kp13_650a-1)/10
gen Merkel14=(kp14_650a-1)/10

* CFA
*factor Merkel1 Merkel4 Merkel7 Merkel8 Merkel11 Merkel14
*rotate
*sem (Merkelfaktor -> Merkel1 Merkel4 Merkel7 Merkel8 Merkel11 Merkel14), ///
	standardized latent(Merkelfaktor) nocapslatent ///
	cov(e.Merkel1*e.Merkel4 e.Merkel4*e.Merkel7 e.Merkel1*e.Merkel7)
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha Merkel1 Merkel4 Merkel7 Merkel8 Merkel11 Merkel14, item


* CFA Alternative mit vier manifesten Variablen 
*factor Merkel1 Merkel7 Merkel8 Merkel14
*rotate
*sem (Merkelfaktor -> Merkel1 Merkel7 Merkel8 Merkel14), ///
	standardized latent(Merkelfaktor) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha Merkel1 Merkel7 Merkel8  Merkel14, item



* Index fr Merkel
egen ix_merkel=rowmean(Merkel1 Merkel2 Merkel3 Merkel4 Merkel5 Merkel6 Merkel7) 
egen ix_merkel13=rowmean(Merkel8 Merkel9 Merkel10 Merkel11 Merkel12 Merkel13 Merkel14)
lab var ix_merkel "Index: Sympathie mit Merkel wkp 2009"
lab var ix_merkel13 "Index: Sympathie mit Merkel wkp 2013"



* Steinbrck Skalometer
*2009
gen Steinb3=(kp3_650k-1)/10
gen Steinb6=(kp6_650k-1)/10

* 2013
gen Steinb8=(kp8_650k-1)/10
gen Steinb9=(kp9_650k-1)/10
gen Steinb10=(kp10_650k-1)/10
gen Steinb11=(kp11_650k-1)/10
gen Steinb12=(kp12_650k-1)/10
gen Steinb13=(kp13_650k-1)/10
gen Steinb14=(kp14_650k-1)/10

* CFA
*factor Steinb3 Steinb6 Steinb10 Steinb13
*rotate
*sem (Steinbfaktor -> Steinb3 Steinb6 Steinb10 Steinb13), ///
	standardized latent(Steinbfaktor) nocapslatent
*estat gof, stat(all)
*estat mindices
*estat residual, stand
*alpha Steinb3 Steinb6 Steinb10 Steinb13, item

* Index fr Steinbrck 2009
egen ix_steinb13=rowmean(Steinb8 Steinb9 Steinb10 Steinb11 Steinb12 Steinb13 Steinb14) 
egen ix_steinb=rowmean(Steinb3 Steinb6) 
lab var ix_steinb "Index: Sympathie mit Steinbrck wkp 2009"

* Index fr Schuble
gen schub3=(kp3_650m-1)/10
gen schub6=(kp6_650m-1)/10
egen ix_schub=rowmean(schub3 schub6) 
lab var ix_schub "Index: Sympathie mit Schuble wkp 2009"

sum ix_merkel ix_steinb ix_schub ix_merkel13 ix_steinb13




**** WKP 2013

***** materielle Interessen

* sociotrophic voting
* Allgemeine wirtschaftliche Lage retrospektiv
tab1 kp8_800 kp11_800 kp14_800
corr kp8_800 kp11_800 kp14_800
recode kp11_800 (1=5) (2=4) (3=3) (4=2) (5=1), gen(natwirt11)
replace natwirt11=(natwirt11-1)/4
label define lnatwirt11 1 "wesentlich besser" 0 "wesentlich schlechter"
label values natwirt11 lnatwirt11
label var natwirt11 "Bewertung wirt. Lage, retrospektiv"

* Allgemeine wirtschaftliche Lage aktuell
tab1 kp8_820 kp11_820 kp14_820
corr kp8_820 kp11_820 kp14_820
recode kp11_820 (1=5) (2=4) (3=3) (4=2) (5=1), gen(natwirta11)
replace natwirta11=(natwirta11-1)/4
label define lnatwirta11 0 "sehr schlecht" 1 "sehr gut"
label values natwirta11 lnatwirta11
label var natwirta11 "Bewertung wirt. Lage, aktuell"


*** persnliche matrielle Lage retrospektiv
recode kp11_760 (1=5) (2=4) (3=3) (4=2) (5=1), gen(perswirt11)
replace perswirt11=(perswirt11-1)/4
label define lperswirt11 1 "wesentlich besser" 0 "wesentlich schlechter"
label values perswirt11 lperswirt11
label var perswirt11 "persnliche wirt. Lage, retrospektiv"


*** Persnlich von der Schuldenkrise betroffen
recode kp10_3040 (1=5) (2=4) (3=3) (4=2) (5=1), gen(betrkrise10)
replace betrkrise10=(betrkrise10-1)/4
lab variable betrkrise10 "Persnlich von Krise betroffen"
label define lbekr10 1 "sehr stark" 0 "berhaupt nicht"
label values betrkrise10 lbekr10

recode kp14_3040 (1=5) (2=4) (3=3) (4=2) (5=1), gen(betrkrise14)
replace betrkrise14=(betrkrise14-1)/4
lab variable betrkrise14 "Persnlich von Krise betroffen"
label define lbekr14 1 "sehr stark" 0 "berhaupt nicht"
label values betrkrise14 lbekr14


*** Nettohaushaltseinkommen
* unter 1500 Euro
recode kp8_2591 (1/5=1) (6/13=0) (.a=.), gen(inc1)
* zwischen 1500 und 4000 Euro
recode kp8_2591 (6/9=1) (1/5 10/13=0) (.a=.), gen(inc2)
* ber 4000 Euro
recode kp8_2591 (10/13=1) (1/9=0) (.a=.), gen(inc3)



*** Beschftigungsstatus - dummies
* Selbststndig 
recode kp8_2380 (2 3=1) (1 2 4 5 6 7 8=0) (.a=.), gen(selbstst)
replace selbstst=0 if kp8_2340==7 | kp8_2340==10
* Beamte
recode kp8_2380 (4=1) (1 2 3 5 6 7 8=0) (.a=.), gen(beamte)
replace beamte=0 if kp8_2340==7 | kp8_2340==10
* Angestellte
recode kp8_2380 (5=1) (1 2 3 4 6 7 8=0) (.a=.), gen(angestellte)
replace angestellte=0 if kp8_2340==7 | kp8_2340==10
* Arbeiter
recode kp8_2380 (6=1) (1 2 3 4 5 7 8=0) (.a=.), gen(arbeiter)
replace arbeiter=0 if kp8_2340==7 | kp8_2340==10
* Arbeitslos
recode kp8_2340 (7=1) (1/6 8/12=0) (.a=.), gen(arbeitslos)
* Rentner
recode kp8_2340 (10=1) (1/9 11/12=0) (.a=.), gen(rentner)

recode kp8_2380 (2 3=1) (4=2) (5=3) (6=4) (1 7 8=.), gen(bstatus)
replace bstatus=5 if kp8_2340==7
replace bstatus=6 if kp8_2340==10
label define lbstat 1 "selbststndig" 2 "Beamte" 3 "Angestellte" 4 "Arbeiter" 5 "arbeitslos" 6 "Rentner"
label values bstatus lbstat
label variable bstatus "Beschftigungsstatus"



***** Kontrollvariablen


*** Bildung 
gen bildung=kp8_2320
recode bildung (1/2=1) (3=2) (4/5=3) (9=.)
lab define lbildung 1 "niedrig" 2 "mittel" 3 "hoch"
lab values bildung lbildung
lab var bildung "Bildungsabschluss"
* Bildung - dummies
gen bild_h = 0
replace bild_h = 1 if kp8_2320 == 5
lab var bild_h "hoher Bildungsabschluss"
gen bild_m = 0
replace bild_m = 1 if kp8_2320 == 3 | kp8_2320 == 4
lab var bild_m "mittlerer Bildungsabschluss"
gen bild_n= 0
replace bild_n = 1 if kp8_2320 == 1 | kp8_2320 == 2
lab var bild_n "niedriger Bildungsabschluss"



*** Geschlecht
recode kp8_2280 (2=1) (1=0), gen(frau)


*** Alter
gen alter=kp1_2290a
replace alter=(alter-18)/57


sum Prfego7 BRegPerf7 MerkelPerf7 SteinbPerf7 ix_merkel ix_steinb ix_schub ///
	ix_unionpid ix_spdpid ix_gruenpid ix_kultdim09 ix_sozdim09 schulden ix_verbEU ///
	ix_verbDeu betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h ///
	selbstst arbeiter angestellte beamte rentner arbeitslos



*****************************************
***** Regressionen
*** Einfluss von Prdispositionen (2009) und materiellen Interessen (2013)
*** OLS-Regression
* Einstellung zur europischen Hilfe
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus, robust
fitstat
est store OLS


*#delimit ;
*esttab OLS using Modell_OLS.rtf, replace
	nonumbers nodepvars onecell
	stats(r2_a N, star fmt(%3,2f %3,0f) labels("Korr. R" "N"))
	b(%3,2f) se(%3,2f)
	starlevels(* 0.05 ** 0.01)
	label varlabel(_cons "Konstante")
	mtitle("Einstellung EU-Hilfe")
	nonotes
	addnote("Robuste Standardfehler in Klammern; * p<0,05  ** p<0,01.");





* Bewertung der Performanz der Bundesregierung in der EU-Krise
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell1

margins, dydx(ix_merkel) predict(outcome(#4))
margins, dydx(ix_schub) predict(outcome(#4))
margins, dydx(ix_unionpid) predict(outcome(#4))
margins, dydx(ix_gruenpid) predict(outcome(#4))
margins, dydx(ix_kultdim09) predict(outcome(#4))
margins, dydx(natwirt11) predict(outcome(#4))
margins, dydx(perswirt11) predict(outcome(#4))





* Bewertung der Performanz von Merkel in der EU-Krise
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell2

margins, dydx(ix_merkel) predict(outcome(#4))
margins, dydx(ix_unionpid) predict(outcome(#4))
margins, dydx(ix_gruenpid) predict(outcome(#4))
margins, dydx(natwirt11) predict(outcome(#4))
margins, dydx(betrkrise10) predict(outcome(#4))





* Bewertung der Performanz von Steinbrck in der EU-Krise
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell3

margins, dydx(ix_steinb) predict(outcome(#4))
margins, dydx(ix_spdpid) predict(outcome(#4))
margins, dydx(schulden5) predict(outcome(#4))
margins, dydx(bstatus) predict(outcome(#4))

	
*#delimit ;
*esttab Modell1 Modell2 Modell3 using ModelleOLOGIT.rtf, replace 
	nonumbers nodepvars onecell
	stats(r2_p N, star fmt(%3,2f %3,0f) labels("Pseudo R" "N"))
	b(%3,2f) se(%3,2f)
	starlevels(* 0.05 ** 0.01 *** 0.001)
	label varlabel(_cons "Konstante")
	mtitle("Perf. BReg" "Perf. Merkel" "Perf. Steinbrck")
	nonotes
	addnote("Standardfehler in Klammern; * p<0,05  ** p<0,01  *** p<0,001.");

	

**************************************************************************
*** Beziehung zwischen Verbundenheit mit der EU und kulturelle Vielfalt
**************************************************************************
	
*** Prefego
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus, robust
est store Modell1
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus, robust
est store Modell2
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus, robust
est store Modell3


	
*** BRegPerf
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell1
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell2
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell3


	
*** MerkelPerf
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell1
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell2
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell3
	
	

*** SteinbPerf
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell1
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell2
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
est store Modell3

	

	
**********************************************************************************
*** Varianzaufklrung durch Prdispositionen und konomische Kalkle im Vergleich
***********************************************************************************
	
	
gen N1=1 if Prfego7!=. & ix_merkel!=. & ix_steinb!=. & ix_schub!=. & ix_unionpid!=. & ix_spdpid!=. & ix_gruenpid!=. ///
	& ix_kultdim09!=. & ix_sozdim09!=. & schulden!=. & ix_verbEU!=. & ix_verbDeu!=. ///
	& betrkrise10!=. & natwirt11!=. & perswirt11!=. & inc1!=. & inc2!=. & alter!=. & frau!=. & bild_h!=. & ///
	bstatus!=. & bstatus!=.a & bstatus!=.c
fre N1

* Einstellung zur europischen Hilfe - Modell Gesamt
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus, robust
fitstat
est store Modell1 

* Einstellung zur europischen Hilfe - Modell konomische Kalkle
reg Prfego7 betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus if N1==1, robust
fitstat
est store Modell2


* Einstellung zur europischen Hilfe - Modell Prdsipositionen
reg Prfego7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden ix_verbEU ix_verbDeu ///
	alter frau bild_h if N1==1, robust
fitstat
est store Modell3


* Einstellung zur europischen Hilfe - Modell Kontrollvariablen
reg Prfego7 alter frau bild_h if N1==1, robust
fitstat
est store Modell4

	
	
	
	
********************************************************************************
********************************************************************************
	
	
gen N2=1 if BRegPerf7!=. & ix_merkel!=. & ix_steinb!=. & ix_schub!=. & ix_unionpid!=. & ix_spdpid!=. & ix_gruenpid!=. ///
	& ix_kultdim09!=. & ix_sozdim09!=. & schulden!=. & ix_verbEU!=. & ix_verbDeu!=. ///
	& betrkrise10!=. & natwirt11!=. & perswirt11!=. & inc1!=. & inc2!=. & alter!=. & frau!=. & bild_h!=. & ///
	bstatus!=. & bstatus!=.a & bstatus!=.c
fre N2

* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell Gesamt
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell1


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell konomische Kalkle
ologit BRegPerf7 betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus if N2==1
fitstat
est store Modell2


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Prdispositionen
ologit BRegPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	alter frau bild_h if N2==1
fitstat
est store Modell3


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Kontrollvariablen
ologit BRegPerf7 alter frau bild_h if N2==1
fitstat
est store Modell4


	
	
	
	
********************************************************************************
********************************************************************************
	
gen N3=1 if MerkelPerf7!=. & ix_merkel!=. & ix_steinb!=. & ix_schub!=. & ix_unionpid!=. & ix_spdpid!=. & ix_gruenpid!=. ///
	& ix_kultdim09!=. & ix_sozdim09!=. & schulden!=. & ix_verbEU!=. & ix_verbDeu!=. ///
	& betrkrise10!=. & natwirt11!=. & perswirt11!=. & inc1!=. & inc2!=. & alter!=. & frau!=. & bild_h!=. & ///
	bstatus!=. & bstatus!=.a & bstatus!=.c
fre N3

* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell Gesamt
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell1


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell konomische Kalkle
ologit MerkelPerf7 betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus if N3==1
fitstat
est store Modell2


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Prdispositionen
ologit MerkelPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	alter frau bild_h if N3==1
fitstat
est store Modell3


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Kontrollvariablen
ologit MerkelPerf7 alter frau bild_h if N3==1
fitstat
est store Modell4



	
	
********************************************************************************
********************************************************************************
	
gen N4=1 if SteinbPerf7!=. & ix_merkel!=. & ix_steinb!=. & ix_schub!=. & ix_unionpid!=. & ix_spdpid!=. & ix_gruenpid!=. ///
	& ix_kultdim09!=. & ix_sozdim09!=. & schulden!=. & ix_verbEU!=. & ix_verbDeu!=. ///
	& betrkrise10!=. & natwirt11!=. & perswirt11!=. & inc1!=. & inc2!=. & alter!=. & frau!=. & bild_h!=. & ///
	bstatus!=. & bstatus!=.a & bstatus!=.c
fre N4

* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell Gesamt
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus
fitstat
est store Modell1


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Modell konomische Kalkle
ologit SteinbPerf7 betrkrise10 natwirt11 perswirt11 inc1 inc2 alter frau bild_h i.bstatus if N4==1
fitstat
est store Modell2


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Prdispositionen
ologit SteinbPerf7 ix_merkel ix_steinb ix_schub ix_unionpid ix_spdpid ix_gruenpid ///
	ix_kultdim09 ix_sozdim09 schulden5 ix_verbEU ix_verbDeu ///
	alter frau bild_h if N4==1
fitstat
est store Modell3


* Bewertung der Performanz der Bundesregierung in der EU-Krise - Kontrollvariablen
ologit SteinbPerf7 alter frau bild_h if N4==1
fitstat
est store Modell4




	
	
	
	
	
	

	

